@@ -13,11 +13,14 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 5747 $
-## |  Last changed: $Date: 2022-01-24 12:14:58 +0100 (Mo, 24 Jan 2022) $
-## |  Last changed by: $Author: wassmer $
+## |  File version: $Revision: 6485 $
+## |  Last changed: $Date: 2022-08-12 13:20:22 +0200 (Fr, 12 Aug 2022) $
+## |  Last changed by: $Author: pahlke $
 ## |
 
+#' @include f_logger.R
+NULL
+
 .getAnalysisResultsSurvival <- function(..., design, dataInput) {
     if (.isTrialDesignGroupSequential(design)) {
         return(.getAnalysisResultsSurvivalGroupSequential(
@@ -176,23 +179,7 @@
                 nPlanned = nPlanned, allocationRatioPlanned = allocationRatioPlanned,
                 thetaH1 = thetaH1, iterations = iterations, seed = seed
             )
-            if (results$.conditionalPowerResults$simulated) {
-                results$conditionalPowerSimulated <- results$.conditionalPowerResults$conditionalPower
-                results$.setParameterType("conditionalPower", C_PARAM_NOT_APPLICABLE)
-                results$.setParameterType("conditionalPowerSimulated", C_PARAM_GENERATED)
-                results$.setParameterType("seed", results$.conditionalPowerResults$.getParameterType("seed"))
-                results$seed <- results$.conditionalPowerResults$seed
-                results$.setParameterType(
-                    "iterations",
-                    results$.conditionalPowerResults$.getParameterType("iterations")
-                )
-                results$iterations <- results$.conditionalPowerResults$iterations
-            } else {
-                results$conditionalPower <- results$.conditionalPowerResults$conditionalPower
-                results$conditionalPowerSimulated <- numeric(0)
-                results$.setParameterType("conditionalPower", C_PARAM_GENERATED)
-                results$.setParameterType("conditionalPowerSimulated", C_PARAM_NOT_APPLICABLE)
-            }
+            .synchronizeIterationsAndSeed(results)
         } else {
             results$.conditionalPowerResults <- .getConditionalPowerSurvival(
                 stageResults = stageResults,
@@ -263,9 +250,8 @@
         # final confidence interval & median unbiased estimate
         startTime <- Sys.time()
         finalConfidenceIntervals <- .getFinalConfidenceIntervalSurvival(
-            design = design,
-            dataInput = dataInput, thetaH0 = thetaH0, stage = stage, directionUpper = directionUpper,
-            tolerance = tolerance
+            design = design, dataInput = dataInput, thetaH0 = thetaH0, stage = stage, 
+            directionUpper = directionUpper, tolerance = tolerance
         )
 
         if (!is.null(finalConfidenceIntervals)) {
@@ -532,7 +518,7 @@
 	        )
 	
 	        # Adjustment for binding futility bounds
-	        if (k > 1 && conditionFunction(bounds[k - 1], border) & design$bindingFutility) {
+			if (k > 1 && !is.na(bounds[k - 1]) && conditionFunction(bounds[k - 1], border) && design$bindingFutility) {		
 	            parameterName <- ifelse(.isTrialDesignFisher(design), "pValues", firstParameterName)
 	
 	            futilityCorr[k] <- .getRootThetaSurvival(
@@ -936,13 +922,7 @@
         results$iterations <- cp$iterations
         results$seed <- cp$seed
         results$simulated <- cp$simulated
-        results$.setParameterType("iterations", ifelse(identical(cp$iterations, C_ITERATIONS_DEFAULT),
-            C_PARAM_DEFAULT_VALUE, C_PARAM_USER_DEFINED
-        ))
-        seed <- .getOptionalArgument("seed", ...)
-        results$.setParameterType("seed", ifelse(!is.null(seed) && !is.na(seed),
-            C_PARAM_USER_DEFINED, C_PARAM_DEFAULT_VALUE
-        ))
+        .updateParameterTypeOfIterationsAndSeed(results, ...)
     } else {
         .stopWithWrongDesignMessage(stageResults$.design)
     }
@@ -1063,7 +1043,7 @@
     stageResults <- .getStageResultsSurvival(
         design = design, dataInput = dataInput, stage = stage,
         thetaH0 = thetaH0, directionUpper = directionUpper
-    )
+    )    
 
     finalConfidenceIntervalGeneral <- rep(NA_real_, 2)
     medianUnbiasedGeneral <- NA_real_
@@ -1151,6 +1131,10 @@
     }
 
     return(list(
+        stage = stage,
+        thetaH0 = thetaH0, 
+        directionUpper = directionUpper,
+        tolerance = tolerance,            
         finalStage = finalStage,
         medianUnbiasedGeneral = medianUnbiasedGeneral,
         finalConfidenceIntervalGeneral = sort(finalConfidenceIntervalGeneral),
@@ -1260,6 +1244,10 @@
     }
 
     return(list(
+        stage = stage,
+        thetaH0 = thetaH0, 
+        directionUpper = directionUpper,
+        tolerance = tolerance,            
         finalStage = finalStage,
         medianUnbiasedGeneral = medianUnbiasedGeneral,
         finalConfidenceIntervalGeneral = sort(finalConfidenceIntervalGeneral),
@@ -1300,6 +1288,10 @@
     }
 
     return(list(
+        stage = stage,
+        thetaH0 = thetaH0, 
+        directionUpper = directionUpper,
+        tolerance = tolerance,            
         finalStage = finalStage,
         medianUnbiased = medianUnbiased,
         finalConfidenceInterval = finalConfidenceInterval
