@@ -14,13 +14,13 @@
 ## |  Contact us for information about our services: info@rpact.com
 ## |  
 ## |  File name: test-f_simulation_enrichment_means.R
-## |  Creation date: 23 February 2022, 14:06:45
-## |  File version: $Revision$
-## |  Last changed: $Date$
-## |  Last changed by: $Author$
+## |  Creation date: 12 August 2022, 09:11:47
+## |  File version: $Revision: 6485 $
+## |  Last changed: $Date: 2022-08-12 13:20:22 +0200 (Fr, 12 Aug 2022) $
+## |  Last changed by: $Author: pahlke $
 ## |  
 
-context("Testing Simulation Enrichment Means Function")
+test_plan_section("Testing Simulation Enrichment Means Function")
 
 
 test_that("'getSimulationEnrichmentMeans': gMax = 2", {
@@ -109,6 +109,8 @@ test_that("'getSimulationEnrichmentMeans': gMax = 2", {
 	    expect_true(nrow(mtx) > 0 && ncol(mtx) > 0)
 	}
 
+	.skipTestIfDisabled()
+
 	suppressWarnings(simResult2 <- getSimulationEnrichmentMeans(design,
 	    populations = 2,
 	    plannedSubjects = c(60, 160), effectList = effectList,
@@ -266,6 +268,8 @@ test_that("'getSimulationEnrichmentMeans': gMax = 2", {
 
 test_that("'getSimulationEnrichmentMeans': gMax = 3", {
 
+	.skipTestIfDisabled()
+
 	# @refFS[Sec.]{fs:sec:reproducibilityOfSimulationResults}
 	# @refFS[Sec.]{fs:sec:enrichmentDesigns}
 	# @refFS[Sec.]{fs:subsec:intersectionTestsEnrichment}
@@ -282,8 +286,6 @@ test_that("'getSimulationEnrichmentMeans': gMax = 3", {
 	# @refFS[Formula]{fs:simulationEnrichmentSelections}
 	# @refFS[Formula]{fs:simulatingEnrichmentEffectSpecification}
 	# @refFS[Formula]{fs:enrichmentRejectionRule}
-	.skipTestIfDisabled()
-
 	effectList <- list(
 	    subGroups = c("S1", "S2", "S12", "R"),
 	    prevalences = c(0.05, 0.35, 0.15, 0.45),
@@ -476,6 +478,8 @@ test_that("'getSimulationEnrichmentMeans': gMax = 3", {
 
 test_that("'getSimulationEnrichmentMeans': gMax = 4", {
 
+	.skipTestIfDisabled()
+
 	# @refFS[Sec.]{fs:sec:reproducibilityOfSimulationResults}
 	# @refFS[Sec.]{fs:sec:enrichmentDesigns}
 	# @refFS[Sec.]{fs:subsec:intersectionTestsEnrichment}
@@ -492,8 +496,6 @@ test_that("'getSimulationEnrichmentMeans': gMax = 4", {
 	# @refFS[Formula]{fs:simulationEnrichmentSelections}
 	# @refFS[Formula]{fs:simulatingEnrichmentEffectSpecification}
 	# @refFS[Formula]{fs:enrichmentRejectionRule}
-	.skipTestIfDisabled()
-
 	effects <- matrix(c(2.3, 3.1, 0.9, 1.2, 2.1, 3.4, 0.9, 0.2), byrow = TRUE, ncol = 8)
 	effectList <- list(subGroups = c("S1", "S2", "S3", "S12", "S13", "S23", "S123", "R"),
 			prevalences = c(0.1, 0.05, 0.1, 0.15, 0.1, 0.15, 0.3, 0.05), effects = effects, 
@@ -611,6 +613,8 @@ test_that("'getSimulationEnrichmentMeans': gMax = 4", {
 
 test_that("'getSimulationEnrichmentMeans': comparison of base and enrichment for inverse normal", {
 
+	.skipTestIfDisabled()
+
 	# @refFS[Sec.]{fs:sec:reproducibilityOfSimulationResults}
 	# @refFS[Sec.]{fs:sec:enrichmentDesigns}
 	# @refFS[Sec.]{fs:sec:simulationFunctions}
@@ -621,8 +625,6 @@ test_that("'getSimulationEnrichmentMeans': comparison of base and enrichment for
 	# @refFS[Formula]{fs:simulationEnrichmentSelections}
 	# @refFS[Formula]{fs:simulatingEnrichmentEffectSpecification}
 	# @refFS[Formula]{fs:enrichmentRejectionRule}
-	.skipTestIfDisabled()
-
 	effectSeq <- seq(0, 0.7, 0.1)
 	effects <- matrix(effectSeq, byrow = TRUE, ncol = 1)
 	effectList <- list(subGroups = "F", prevalences = 1, stDevs = 1.3, effects = effects)
@@ -664,6 +666,8 @@ test_that("'getSimulationEnrichmentMeans': comparison of base and enrichment for
 
 test_that("'getSimulationEnrichmentMeans': comparison of base and enrichment for Fisher combination", {
 
+	.skipTestIfDisabled()
+
 	# @refFS[Sec.]{fs:sec:reproducibilityOfSimulationResults}
 	# @refFS[Sec.]{fs:sec:enrichmentDesigns}
 	# @refFS[Sec.]{fs:sec:simulationFunctions}
@@ -674,8 +678,6 @@ test_that("'getSimulationEnrichmentMeans': comparison of base and enrichment for
 	# @refFS[Formula]{fs:simulationEnrichmentSelections}
 	# @refFS[Formula]{fs:simulatingEnrichmentEffectSpecification}
 	# @refFS[Formula]{fs:enrichmentRejectionRule}
-	.skipTestIfDisabled()
-
 	effectSeq <- seq(0, 0.7, 0.1)
 	effects <- matrix(effectSeq, byrow = TRUE, ncol = 1)
 	effectList <- list(subGroups = "F", prevalences = 1, stDevs = 1.3, effects = effects)
